/****************************************
 * Reception et affichage des donnees de capteurs
 * Module 2 entrees analogiques vers Midi
 * Interface-Z
 * Sensors data reception and display from
 * 2 analogical ways
 *****************************************/

// Importer la library the Midibus
// http://smallbutdigital.com/themidibus.php
import themidibus.*; 
MidiBus myBus; 

PFont policeperso;

void setup() {
  size(400, 380);
  smooth();
  noStroke();
  background(0);

  // Liste des peripheriques Midi disponibles sur l'ordinateur
  // Displaying Midi devices existing on the computer  
  MidiBus.list(); 

  // Ouverture de port (this, In, Out)
  // Choisir le numero du peripherique dans la liste
  // In et Out etant les numeros des peripheriques entrant et sortant
  // Open Midi port (this, In, Out)
  // Choose the appropriate Midi device from the list
  // In and Out being the corresponding In and Out devices
  myBus = new MidiBus(this, 0, -1);
  // -1 pour ne pas ouvrir ce port
  // -1 in order not to open this port

  policeperso = loadFont("AonCariCeltic-32.vlw");
  textFont(policeperso, 32);
}

// Reception des capteurs analogiques
// Receiving analogical sensors
int[] capteur = new int[2];
int numero;
int[] registre1 = new int[24];
int[] registre2 = new int[24];

void controllerChange(int channel, int number, int value) {
  // Recoit les messages Midi de type Control Change
  // Receive Control Change messages
  if ((number >= 0) && (number <= 1)) {
    numero = number;
    capteur[numero] = value;
  }

  // registre a decalage pour le premier capteur
  // register for the first sensor
  if (numero == 0) {
    for (int i =23; i>0; i = i-1) {
      registre1[i] = registre1[i-1];
    }
    // une fois la case 0 recopiee sur la case 1,
    // transferer la valeur nouvelle du capteur dans la case 0 du registre  
    registre1[0] = capteur[0];
  }
  // registre a decalage pour le second capteur
  // register for the second sensor
  if (numero == 1) {
    for (int i =23; i>0; i = i-1) {
      registre2[i] = registre2[i-1];
    }
    // une fois la case 0 recopiee sur la case 1,
    // transferer la valeur nouvelle du capteur dans la case 0 du registre  
    registre2[0] = capteur[1];
  }
  println("Control Change : Canal "+channel+" Numero "+number+" Valeur "+capteur);
}

void draw() {
  background(0);
  fill(255);
  text("2 Analogiques Midi", 30, 30);
  text(capteur[0], 30, 100);
  text(capteur[1], 30, 260);
  
  // Affichage du premier capteur
  // Displaying the first sensor
  // Affichage de 24 Blocs bleus
  for (int i =0; i<=23; i = i+1 ) {
    fill(224, 102, 10);
    rect(90 + (i*12), 40, 10, 128);
  }
  // Affichage d'un bloc clair dont la hauteur
  // depend de la valeur du capteur
  for (int j = 0; j<=23; j = j+1) {
    fill(240, 162, 40+j*2);
    rect(90 + (j*12), 40 + 127 - registre1[j], 10, registre1[j]);
  }
  
  // Affichage du deuxieme capteur
  // Displaying the second sensor
  // Affichage de 24 Blocs bleus
  for (int i =0; i<=23; i = i+1 ) {
    fill(224, 102, 10);
    rect(90 + (i*12), 200, 10, 128);
  }
  for (int j = 0; j<=23; j = j+1) {
    fill(240, 162, 40+j*2);
    rect(90 + (j*12), 200 + 127 - registre2[j], 10, registre2[j]);
  }  
  
  
}

